import java.io.IOException;
import java.net.MalformedURLException;
import java.util.Calendar;
import java.util.Date;
import java.util.Enumeration;
import java.util.Hashtable;
import java.util.Vector;

import helma.xmlrpc.XmlRpc;

import helma.xmlrpc.XmlRpcClient;
import helma.xmlrpc.XmlRpcException;

/**
 * <b><code>SchedulerClient</code></b> is an XML-RPC client
 *   that makes XML-RPC requests to <code>Scheduler</code>.
 * 
 * @version 1.0
 */
public class SchedulerClient {

    /**
     * <p>
     * Add events to the Scheduler.
     * </p>
     *
     * @param client <code>XmlRpcClient</code> to connect to
     */
    public static void addEvents(XmlRpcClient client) 
        throws XmlRpcException, IOException {
          
        System.out.println("\nAdding events...\n");          
          
        // Parameters for events
        Vector params = new Vector();
        
        // Add an event for next month
        params.addElement("Proofread final draft");
            
        Calendar cal = Calendar.getInstance();
        cal.add(Calendar.MONTH, 1);
        params.addElement(cal.getTime());
            
        // Add the event
        if (((Boolean)client.execute("scheduler.addEvent", params))
                            .booleanValue()) {
            System.out.println("Event added.");
        } else {
            System.out.println("Could not add event.");
        }        
            
        // Add an event for tomorrow
        params.clear();
        params.addElement("Submit final draft");
            
        cal = Calendar.getInstance();
        cal.add(Calendar.DAY_OF_MONTH, 1);
        params.addElement(cal.getTime());
        
        // Add the event
        if (((Boolean)client.execute("scheduler.addEvent", params))
                            .booleanValue()) {
            System.out.println("Event added.");
        } else {
            System.out.println("Could not add event.");
        }        
            
    }
    
    /**
     * <p>
     * List the events currently in the Scheduler.
     * </p>
     *
     * @param client <code>XmlRpcClient</code> to connect to
     */
    public static void listEvents(XmlRpcClient client) 
        throws XmlRpcException, IOException {  
          
        System.out.println("\nListing events...\n");                

        // Get the events in the scheduler
        Vector params = new Vector();
        Vector events = 
            (Vector)client.execute("scheduler.getListOfEvents", params);
        for (int i=0; i<events.size(); i++) {
            System.out.println((String)events.elementAt(i));
        }
    }
  
    /**
     * <p>
     * Static entry point for the demo.
     * </p>
     */
    public static void main(String args[]) {
        
        try {
            // Use the Apache Xerces SAX Parser Implementation
            XmlRpc.setDriver("org.apache.xerces.parsers.SAXParser");
          
            // Connect to server
            XmlRpcClient client = 
                new XmlRpcClient("http://localhost:8585/");                                         
              
            // Add some events
            addEvents(client);                        
            
            // List events
            listEvents(client);            
        
        } catch (Exception e) {
            System.out.println(e.getMessage());
        }
        
    }
    
}